@@ -1,12 +1,14 @@
 from datetime import date
 
-from ..core import ChineseNewYearCalendar, WesternCalendar
-from ..core import IslamicMixin
+from ..core import (
+    IslamicMixin, ChineseNewYearCalendar,
+    SAT, SUN
+)
 from ..registry_tools import iso_register
 
 
 @iso_register('MY')
-class Malaysia(ChineseNewYearCalendar, WesternCalendar, IslamicMixin):
+class Malaysia(IslamicMixin, ChineseNewYearCalendar):
     "Malaysia"
     include_nuzul_al_quran = True
     include_eid_al_fitr = True
@@ -17,7 +19,11 @@ class Malaysia(ChineseNewYearCalendar, WesternCalendar, IslamicMixin):
     include_islamic_new_year = True
     include_prophet_birthday = True
 
-    FIXED_HOLIDAYS = WesternCalendar.FIXED_HOLIDAYS + (
+    # Most of th Malaysian territory uses these Week-end days
+    WEEKEND_DAYS = (SAT, SUN)
+    # TODO: Add calendar exceptions
+
+    FIXED_HOLIDAYS = ChineseNewYearCalendar.FIXED_HOLIDAYS + (
         (2, 1, "Federal Territory Day"),
         (5, 1, "Workers' Day"),
         (8, 31, "National Day"),
