@@ -1,16 +1,16 @@
 from datetime import timedelta
-from ..core import WesternCalendar, OrthodoxMixin
+from ..core import OrthodoxCalendar
 from ..registry_tools import iso_register
 
 
 @iso_register('BY')
-class Belarus(WesternCalendar, OrthodoxMixin):
+class Belarus(OrthodoxCalendar):
     'Belarus'
     "as of http://president.gov.by/en/holidays_en/"
 
     include_christmas = False
 
-    FIXED_HOLIDAYS = WesternCalendar.FIXED_HOLIDAYS + (
+    FIXED_HOLIDAYS = OrthodoxCalendar.FIXED_HOLIDAYS + (
         (1, 2, "Day After New Year"),
         (1, 7, "Christmas (Orthodox)"),
         (3, 8, "International Women's Day"),
@@ -24,15 +24,10 @@ class Belarus(WesternCalendar, OrthodoxMixin):
     # https://en.wikipedia.org/wiki/Radonitsa
 
     def get_radonitsa(self, year):
-        # Second Monday after easter sunday
-        return self.get_easter_sunday(year) + timedelta(days=15)
-
-    def get_day_after_radonitsa(self, year):
-        # one day after the Radonsista Monday
-        return self.get_radonitsa(year) + timedelta(days=1)
+        # 9 Days after the Orthodox easter sunday
+        return self.get_easter_sunday(year) + timedelta(days=9)
 
     def get_variable_days(self, year):
         days = super().get_variable_days(year)
-        days.append((self.get_radonitsa(year), "Radonista"))
-        days.append((self.get_day_after_radonitsa(year), "Radonista Holiday"))
+        days.append((self.get_radonitsa(year), "Radonitsa"))
         return days
