@@ -1,11 +1,11 @@
 from datetime import date
 
-from ..core import WesternCalendar, ChristianMixin
+from ..core import WesternCalendar
 from ..registry_tools import iso_register
 
 
 @iso_register('HR')
-class Croatia(WesternCalendar, ChristianMixin):
+class Croatia(WesternCalendar):
     'Croatia'
 
     FIXED_HOLIDAYS = WesternCalendar.FIXED_HOLIDAYS + (
