@@ -1,9 +1,9 @@
-from ..core import WesternCalendar, ChristianMixin
+from ..core import WesternCalendar
 from ..registry_tools import iso_register
 
 
 @iso_register('HU')
-class Hungary(WesternCalendar, ChristianMixin):
+class Hungary(WesternCalendar):
     'Hungary'
 
     include_easter_sunday = True
