@@ -13,3 +13,9 @@ class UnsupportedDateType(CalendarError):
     """
     Raised when trying to use an unsupported date/datetime type.
     """
+
+
+class ISORegistryError(CalendarError):
+    """
+    Raised when you are trying to register a non-Calendar object
+    """
